/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.quality.data;

import java.time.LocalDateTime;

import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;

/**
 * Storage element corresponding to a {@Link IProjectRootElement}. It stores the last refresh time
 * as {@link LocalDateTime}, its respective {@link ITopLevelElement} and the {@link MetricTreeNode}
 * storing the data
 * 
 * @author groh
 */
public class DataRootElement {

	/** the last time a metric tree was refreshed */
	private LocalDateTime lastRefresh;

	/** the last time the metric tree was refreshed */
	private ITopLevelElement topLevelElement;

	/** Root {@link MetricTreeNode} for the metric tree containg all data */
	private MetricTreeNode rootNode;

	/**
	 * Constructor: Creates a new instance of the {@link DataRootElement}.
	 * 
	 * @param lastRefresh
	 *            the last time the rootNode was refreshed
	 * @param topLevelElement
	 *            the {@link ITopLevelElement} of the project
	 * @param rootNode
	 *            the root node of the metric data tree
	 */
	public DataRootElement(LocalDateTime lastRefresh, ITopLevelElement topLevelElement,
			MetricTreeNode rootNode) {
		super();
		this.lastRefresh = lastRefresh;
		this.topLevelElement = topLevelElement;
		this.rootNode = rootNode;
	}

	/** Returns lastRefresh. */
	public LocalDateTime getLastRefresh() {
		return lastRefresh;
	}

	/** Sets lastRefresh. */
	public void setLastRefresh(LocalDateTime lastRefresh) {
		this.lastRefresh = lastRefresh;
	}

	/** Returns topLevelElement. */
	public ITopLevelElement getTopLevelElement() {
		return topLevelElement;
	}

	/** Sets topLevelElement. */
	public void setTopLevelElement(ITopLevelElement topLevelElement) {
		this.topLevelElement = topLevelElement;
	}

	/** Returns rootNode. */
	public MetricTreeNode getRootNode() {
		return rootNode;
	}

	/** Sets rootNode. */
	public void setRootNode(MetricTreeNode metricTreeNode) {
		this.rootNode = metricTreeNode;
	}
}
