/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.quality.data;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.model.IProjectRootElement;

/**
 * Class containing all computed metrics for the current af3 instance.
 * 
 * @author groh
 */
public class MetricDataManager {

	/** a map to lookup the corresponding tree node for any {@link EObject} */
	private Map<EObject, MetricTreeNode> treeNodeLookupTable;

	/** a map to lookup the corresponding root tree node for a project */
	private Map<IProjectRootElement, DataRootElement> dataRootElementMap;

	/**
	 * Constructor: Creates a new instance of the MetricDataManager.
	 */
	public MetricDataManager() {
		dataRootElementMap = new HashMap<>();
		treeNodeLookupTable = new HashMap<>();
	}

	/**
	 * @return the lookup mapping between {@link EObject} and a {@link MetricTreeNode}.
	 */
	public Map<EObject, MetricTreeNode> getTreeNodeLookupTable() {
		return treeNodeLookupTable;
	}

	/**
	 * @return the map between {@link IProjectRootElement} and the corresponding root
	 *         {@link DataRootElement}.
	 */
	public Map<IProjectRootElement, DataRootElement> getDataRootElementMap() {
		return dataRootElementMap;
	}
}
