/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.quality.service;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.ext.quality.IMetricProvider;
import org.fortiss.tooling.ext.quality.MetricUpdateListener;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;

/**
 * A service for performing metric extraction and analysis.
 * 
 * @author groh
 */
public interface IModelQualityService {
	/** Returns the service instance. */
	public static IModelQualityService getInstance() {
		return ModelQualityService.getInstance();
	}

	/** Registers the metric provider with the service. */
	<T extends EObject> void registerMetricProvider(IMetricProvider<T> provider,
			Class<T> modelElementClass);

	/** Schedules an analysis of the metrics and processes them. */
	void scheduleMetricCollection(ITopLevelElement top);

	/**
	 * Registers the provided {@link MetricUpdateListener} to be called when the metrics are
	 * updated.
	 * 
	 * @param listener
	 *            to be registered
	 */
	void registerMetricUpdateListener(MetricUpdateListener listener);
}
