/*--------------------------------------------------------------------------+
|                                                                          |
| Copyright 2022 fortiss GmbH         						               |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.ui.util;

import org.eclipse.core.databinding.conversion.Converter;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.variability.model.presence.PresenceCondition;
import org.fortiss.variability.presence.compiler.PresenceConditionCompiler;

/** Converter from {@link String} to {@link PresenceCondition}. */
public class StringToPresenceConditionConverter extends Converter<String, PresenceCondition> {

	/**
	 * Context that is used to parse the presence conditions. E.e. any element in
	 * the same containment tree as the literals in the {@link PresenceCondition}.
	 */
	protected EObject context;

	/**
	 * Constructor.
	 * 
	 * @param context
	 *            Context that is used to parse the presence conditions. E.e.
	 *            any element in the same containment tree as the literals in
	 *            the {@link PresenceCondition}.
	 */
	public StringToPresenceConditionConverter(EObject context) {
		super(String.class, PresenceCondition.class);

		this.context = context;
	}

	/** {@inheritDoc} */
	@Override
	public PresenceCondition convert(String fromObject) {
		String str = fromObject;

		PresenceConditionCompiler c = new PresenceConditionCompiler();
		PresenceCondition pc = c.compilePresenceCondition(context, str);

		return pc;
	}
}
