/*-------------------------------------------------------------------------+
| Copyright 2022 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.clipboard;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;

/**
 * The {@link ClipboardObjectWithResource} is a container that stores an {@link EObject} together
 * with its (original) resource. This is for example needed to not lose the reference to this
 * resource when moving the {@link EObject} via the clipboard.
 * 
 * @author bergemann
 */
public class ClipboardObjectWithResource {

	/** The element as main artifact of this container. */
	private EObject element;

	/** The original resource of the element. */
	private Resource resourceOfCurrentElement;

	/**
	 * Constructor (The contained artifacts can also be changed later via getter/setter).
	 * 
	 * @param element
	 *            The element that should be stored as main artifact inside this container object
	 * @param originalResource
	 *            The resource of the element that should is stored in the container object
	 */
	public ClipboardObjectWithResource(EObject element, Resource originalResource) {
		setElement(element);
		setResource(originalResource);
	}

	/** Returns the (main) element of this container. */
	public EObject getElement() {
		return element;
	}

	/** Sets the (main) element of this container. */
	public void setElement(EObject element) {
		this.element = element;
	}

	/** Returns the resource of the currently stored element of this container. */
	public Resource getResource() {
		return resourceOfCurrentElement;
	}

	/** Sets the resource of the currently stored element of this container. */
	public void setResource(Resource resourceOfElement) {
		this.resourceOfCurrentElement = resourceOfElement;
	}
}
